function p = probability_liquidation(coefficients, age, prev_assets, ...
returns, flows)
% 
%#
%# # License
%#
%# =============================================================================
%#
%# Copyright 2011, Dimitrios Bisias, Andrew W. Lo, and Stavros Valavanis
%#
%# COPYRIGHT STATUS:  This work was funded in whole or in part by the Office of 
%# Financial Research under U.S. Government contract TOSOFR-11-C-0001, and is, 
%# therefore, subject to the following license: The Government is granted for 
%# itself and others acting on its behalf a paid-up, nonexclusive, irrevocable, 
%# worldwide license to reproduce, prepare derivative works,
%# distribute copies to the public, perform and display the work.  
%# All other rights are reserved by the copyright owner.
%# 
%# THIS SOFTWARE IS PROVIDED "AS IS".  YOU ARE USING THIS SOFTWARE AT YOUR OWN
%# RISK.  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
%# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
%# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS, CONTRIBUTORS, OR
%# THE UNITED STATES GOVERNMENT BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
%# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
%# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
%# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
%# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
%# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
%# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
%# 
%# =============================================================================
%#
%# # Synopsis
%#
%# probability_liquidation - calculates the probability of fund liquidation.
%# Takes as input coefficients generated from probability_liquidation_model.
%#			
%# # Introduction 
%# NOTE: PART OF A SET OF 2 RELATED FILES:
%#
%#  * probability_liquidation.m
%#  * probability_liquidation_model.m
%#
%# Chan, Getmansky, Haas, and Lo (2006a, 2006b) consider the broader impact 
%# of hedge funds on systemic risk by examining the unique risk/return 
%# profiles of hedge funds at both the individual-fund and 
%# aggregate-industry levels and propose three new risk measures for hedge 
%# fund investments. In the third risk measure, the authors create a measure of 
%# the probability of hedge fund liquidation by running a logit model on a set 
%# of factors driving hedge fund performance. 
%# 
%# The authors describe three metrics in their paper; we concetrate on Hedge
%# Fund Liquidation Probability. This metric is discussed extensively in 
%# Section F.7.1.2, and specifically in equations (A.106) and (A.107), in 
%# Bisias et al. (2012).  Please refer to those pages for an extensive 
%# description of the code in this module and the required inputs. 
%#
%# # Input Description
%#
%# ## Input arg: coefficients 
%# Regression coefficients B0-B8 are inputted as a vector ordered as follows: 
%# B0 - Age; B1 - assets at time t-1; B2, B3, B4 - returns at time t, t-1, and 
%# t-2; B5, B6, B7 - flows at time t, t-1, and t-2; B8 - a y-intercept constant.
%# Note: This is generated by probability_liquidation_model.m.
%# ### Type: float
%# ### Range: (-inf,+inf)
%# ### Dimensions: 9x1 matrix
%#
%# 1.  Rows represent different independent variables.
%#
%#
%# ## Input arg: age 
%# The age of the hedge fund.
%# ### Type: float
%# ### Range: (0,+inf)
%# ### Dimensions: scalar
%#
%# ## Input arg: prev_assets
%# The assets under management of the hedge fund last year.
%# ### Type: float
%# ### Range: (0,+inf)
%# ### Dimensions: scalar 
%#
%# ## Input arg: returns
%# The returns of the hedge fund in reverse chronological order; i.e. returns(1) 
%# are the current returns.  
%# Note: This ordering is required to match the sequence of 
%# regression coefficients in Input arg coeff.  While coeff has 9 values, its 
%# coefficients for returns are ordered in descending order as t, t-1, and t-2.
%# Thus, returns which is multiplied times its respective coeff regression
%# coefficients must also be descending.
%# ### Type: float
%# ### Range: (-inf,+inf)
%# ### Dimensions: 3x1 matrix
%#
%# 1.  Rows represent dates. (descending)
%#
%#
%# ## Input arg: flows
%# The flows of the last 3 years in reverse chronological order; i.e flows(1) 
%# are the current flows.
%# Note: This ordering is required to match the sequence of 
%# regression coefficients in Input arg coeff.  While coeff has 9 values, its 
%# coefficients for flows are ordered in descending order as t, t-1, and t-2.
%# Thus, flows which is multiplied times its respective coeff regression
%# coefficients must also be descending.
%# ### Type: float
%# ### Range: (-inf,+inf)
%# ### Dimensions: 3x1 matrix
%#
%# 1.  Rows represent dates. (descending)
%#
%#
%# # Output Description
%# ## Output arg: p 
%# Estimated liquidation probability generated using regression equation
%# and hedge-fund specific data.
%# ### Type: float
%# ### Range: (0,1)
%# ### Dimensions: scalar
%#
%# # Examples
%# NOTE: Numbers used in the examples are arbitrary valid values.  
%# They do not necessarily represent a realistic or plausible scenario.
%# 
%#     coefficients = [.11, -.07, .09, -.16, .08, .03, .05, -.08, .09]'
%#     age = 20
%#     prev_assets = 4.6
%#     returns = [0.05, 0.03, 0.1]'
%#     flows = [.9, .7, 1.3]'
%#
%#     p = probability_liquidation(coefficients, age, prev_assets, ...
%#     returns, flows)
%#
%# # References
%#
%# [Chan et al. (2006a). Do hedge funds increase systemic risk?. 
%# Economic Review-Federal Reserve Bank of Atlanta, 91(4), 49.] 
%# (http://web.mit.edu/~alo/www/Papers/EcRev2007.pdf)
%#
%# [Chan et al. (2006b). Systemic risk and hedge funds. The Risks of Financial 
%# Institutions. Chicago, IL: University of Chicago Press, 235-330.] 
%# (http://www.nber.org/papers/w11200.pdf) 
%#
%# [Bisias et al. (2012). A survey of systemic risk analytics 
%# (Working paper #0001). Washington, DC: 
%# Office of Financial Research, 133-135.]
%# (http://www.treasury.gov/initiatives/wsr/ofr/Documents/
%# OFRwp0001_BisiasFloodLoValavanis_ASurveyOfSystemicRiskAnalytics.pdf)
%#
%# # Code

% Run warning message
warning('OFRwp0001:UntestedCode', ...
    ['This version of the source code is very preliminary, ' ...
     'and has not been thoroughly tested. Users should not rely on ' ...
     'these calculations.']);


%
% Parameters:
% coefficient The 9 coeffs returned by the function 
% probability_liquidation_model
% age The age of the fund
% prev_assets The assets under management of the fund last year
% returns A 3x1 vector for the returns of the last 3 years going backwards
% i.e returns(1) are the current returns
% flows A 3x1 vector for the flows of the last 3 years going backwards
% i.e flows(1) are the current flows

linear_term = coefficients'*[1 age prev_assets returns' flows']';

p = exp(linear_term)/(1+exp(linear_term));