function [q_stats sys_liquidity_ind] = systemic_liquidity_indicator( ...
funds_returns, assets_under_management)
% 
%#
%# # License
%#
%# =============================================================================
%#
%# Copyright 2011, Dimitrios Bisias, Andrew W. Lo, and Stavros Valavanis
%#
%# COPYRIGHT STATUS:  This work was funded in whole or in part by the Office of 
%# Financial Research under U.S. Government contract TOSOFR-11-C-0001, and is, 
%# therefore, subject to the following license: The Government is granted for 
%# itself and others acting on its behalf a paid-up, nonexclusive, irrevocable, 
%# worldwide license to reproduce, prepare derivative works,
%# distribute copies to the public, perform and display the work.  
%# All other rights are reserved by the copyright owner.
%# 
%# THIS SOFTWARE IS PROVIDED "AS IS".  YOU ARE USING THIS SOFTWARE AT YOUR OWN
%# RISK.  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
%# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
%# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS, CONTRIBUTORS, OR
%# THE UNITED STATES GOVERNMENT BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
%# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
%# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
%# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
%# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
%# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
%# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
%# 
%# =============================================================================
%#
%# # Synopsis
%#
%# systemic_liquidity_indicator - calculates the Q-stats for each fund and 
%# the systemic liquidity indicator.
%#
%# # Introduction
%#
%# Chan, Getmansky, Haas, and Lo (2006a, 2006b) consider the broader impact 
%# of hedge funds on systemic risk by examining the unique risk/return 
%# profiles of hedge funds at both the individual-fund and 
%# aggregate-industry levels and propose three new risk measures for hedge 
%# fund investments. The first measure is an autocorrelation-based measure 
%# used to proxy hedge fund illiquidity exposures similar to that in 
%# Getmansky, Lo, and Makarov (2004) 
%# 
%# Autocorrelation-Based Measures: For a given monthly return series of a 
%# hedge fund, the first 6 autocorrelation coefficients are estimated. The 
%# Q statistic, proposed by Ljung & Box in Ljung and Box (1978) is then 
%# calculated. 
%# 
%# In terms of defining an overall measure of systemic risk (or 
%# illiquidity) in the hedge fund sector, the authors propose using a 
%# cross-sectional weighted average of hedge funds rolling first-order 
%# autocorrelations (systemic liquidity indicator). 
%#
%# # Input Description
%# 
%# ## Input arg: funds_returns
%# A matrix of monthly fund returns.
%# ### Type: float
%# ### Range: (-inf,+inf)
%# ### Dimensions: TxK matrix
%#
%# 1.  Rows represent each of T periods.  T >= 7.
%# 2.  Columns represent returns for each of K funds.
%# 
%#
%# ## Input arg: assets_under_management
%# Assets under management for the different funds.
%# ### Type: float
%# ### Range: (0,+inf)
%# ### Dimensions: Kx1 matrix
%#
%# 1.  Rows represent each of K funds
%#
%#
%# # Output Description
%#
%# ## Output arg: q_stats
%# The q-statistics for the different funds' returns.
%# ### Type: float
%# ### Range: (0,+inf)
%# ### Dimensions: Kx1 matrix
%#
%# 1.  Rows represent each of K funds
%#
%#
%# ## Output arg: sys_liquidity_ind
%# The systemic liquidity indicator
%# ### Type: float
%# ### Range: (-inf,+inf)
%# ### Dimensions: scalar
%#
%# # Examples
%# NOTE: Numbers used in the examples are arbitrary valid values.  
%# They do not necessarily represent a realistic or plausible scenario.
%#
%#     funds_returns = ...
%#     [0.0595, 0.1211,-0.0806;
%#      0.1091, 0.0897,-0.0254;
%#      0.0901, 0.0714, 0.0915;
%#      0.1086, 0.0033,-0.1173;
%#      0.0287, 0.1352, 0.0291;
%#      -0.0523, 0.0700, 0.0020;
%#      0.0614, 0.0151, 0.0919];
%#     
%#     assets_under_management = ...
%#     [453.7977;
%#      432.3915;
%#      133.1710];
%#     
%#     [q_stats sys_liquidity_ind] = systemic_liquidity_indicator( ...
%#     funds_returns, assets_under_management);
%#
%# # References
%#
%# [Chan et al. (2006a). Do hedge funds increase systemic risk?. 
%# Economic Review-Federal Reserve Bank of Atlanta, 91(4), 49.] 
%# (http://web.mit.edu/~alo/www/Papers/EcRev2007.pdf)
%#
%# [Chan et al. (2006b). Systemic risk and hedge funds. The Risks of Financial 
%# Institutions. Chicago, IL: University of Chicago Press, 235-330.] 
%# (http://www.nber.org/papers/w11200.pdf) 
%#
%# [Bisias et al. (2012). A survey of systemic risk analytics 
%# (Working paper #0001). 
%# Washington, DC: Office of Financial Research, 133-134.]
%# (http://www.treasury.gov/initiatives/wsr/ofr/Documents/
%# OFRwp0001_BisiasFloodLoValavanis_ASurveyOfSystemicRiskAnalytics.pdf)
%#
%# # Code

% Run warning message
warning('OFRwp0001:UntestedCode', ...
    ['This version of the source code is very preliminary, ' ...
     'and has not been thoroughly tested. Users should not rely on ' ...
     'these calculations.']);

%
% Paramaters:
% funds_returns The monthly returns of the funds. A nxk matrix.  Rows are 
% the different periods  Columns are the different funds. 
% assets_under_management The assets under management for the different
% funds A kx1 vector
% Outputs:
% q_stats The q-statistics for the different funds' returns. A kx1 vector
% sys_liquidity_ind The systemic liquidity indicator

num_funds = size(funds_returns,2);
q_stats = zeros(num_funds,1); 

for i=1:num_funds
    % Find the Ljung-Box statistic
    [h pval stat] = lbqtest(funds_returns(:,i),'lags',6);
    q_stats(i) = stat;
    
    rho = autocorr(funds_returns(:,i), 1);
    % 1st order autocorrelation
    rhos(i) = rho(2);
end

sys_liquidity_ind = rhos*assets_under_management/sum(assets_under_management);








